pub struct BepInEx { /* private fields */ }Expand description
Loader implementation for BepInEx, a general-purpose Unity mod loader.
BepInEx uses Doorstop to inject into the game process and supports several sub-directories for plugins, patchers, monomod assemblies, and config.
Examples
use loadsmith_loader::{BepInEx, Loader};
let loader = BepInEx::with_default_rules();
assert_eq!(loader.id(), "BepInEx");Implementations
Sourceimpl BepInEx
impl BepInEx
Sourcepub fn with_rules(package_install_ruleset: OwnedInstallRuleset) -> Self
pub fn with_rules(package_install_ruleset: OwnedInstallRuleset) -> Self
Creates a BepInEx loader with a custom install ruleset.
Sourcepub fn with_default_rules() -> Self
pub fn with_default_rules() -> Self
Creates a BepInEx loader with the default install rules.
Default routes:
BepInEx/config(mutable, flat)BepInEx/patchersBepInEx/coreBepInEx/monomod(files with.mm.dllextension)BepInEx/plugins(files with.dllextension) — default rule
Sourcepub fn add_install_rule(&mut self, rule: impl Into<InstallRule>)
pub fn add_install_rule(&mut self, rule: impl Into<InstallRule>)
Adds an install rule to the end of the ruleset.
Sourcepub fn insert_install_rule(
&mut self,
index: usize,
rule: impl Into<InstallRule>,
)
pub fn insert_install_rule( &mut self, index: usize, rule: impl Into<InstallRule>, )
Inserts an install rule at the given index.