pub struct LaunchArgs { /* private fields */ }Expand description
Arguments, environment variables, and an optional wrapper binary to use when launching a game with a mod loader.
Build one using the builder methods (arg,
env, wrapper), then call
apply to configure a
std::process::Command.
Examples
use loadsmith_loader::LaunchArgs;
use std::process::Command;
let args = LaunchArgs::new()
.arg("--doorstop-enable")
.arg("true")
.env("DOORSTOP_ENABLE", "TRUE");
let mut cmd = Command::new("game.exe");
args.apply(&mut cmd);
assert_eq!(cmd.get_args().collect::<Vec<_>>(), ["--doorstop-enable", "true"]);Implementations
Sourceimpl LaunchArgs
impl LaunchArgs
Sourcepub fn env(self, key: impl Into<OsString>, value: impl Into<OsString>) -> Self
pub fn env(self, key: impl Into<OsString>, value: impl Into<OsString>) -> Self
Sets an environment variable.
Sourcepub fn wrapper(self, wrapper: impl Into<PathBuf>) -> Self
pub fn wrapper(self, wrapper: impl Into<PathBuf>) -> Self
Sets a wrapper binary (e.g. wine or proton) that the command
should be launched through.
Sourcepub fn get_wrapper(&self) -> Option<&Path>
pub fn get_wrapper(&self) -> Option<&Path>
Returns the wrapper binary path, if set.
Sourcepub fn apply(self, command: &mut Command)
pub fn apply(self, command: &mut Command)
Applies these arguments, environment, and optional wrapper to a
std::process::Command.
When a wrapper is set the original command’s program and arguments become sub-arguments of the wrapper.