Lovely

Struct Lovely 

pub struct Lovely;
Loader implementation for Lovely, a mod loader for the visual-novel game Doki Doki Literature Club!.

Lovely uses a mods directory for packages and a version.dll proxy DLL.

Examples

use loadsmith_loader::{Lovely, Loader};

let loader = Lovely::new();
assert_eq!(loader.id(), "Lovely");

Implementations

Source

impl Lovely

pub fn new() -> Self

Creates a new Lovely loader.