pub struct MelonLoader { /* private fields */ }Expand description
Loader implementation for MelonLoader, a mod loader for Unity games.
MelonLoader supports two installation schemes:
- Legacy — routes files to
UserLibs,Plugins,MelonLoader/Managed,MelonLoader/Libs,MelonLoader,Mods, andUserData/ModManager. - Recursive — routes all files into
Modsand keepsUserDatafor mutable config.
Examples
use loadsmith_loader::{MelonLoader, Loader};
let loader = MelonLoader::with_default_legacy_rules();
assert_eq!(loader.id(), "MelonLoader");Implementations
Sourceimpl MelonLoader
impl MelonLoader
Sourcepub fn with_rules(package_install_ruleset: OwnedInstallRuleset) -> Self
pub fn with_rules(package_install_ruleset: OwnedInstallRuleset) -> Self
Creates a MelonLoader with a custom install ruleset.
Sourcepub fn with_default_legacy_rules() -> Self
pub fn with_default_legacy_rules() -> Self
Creates a MelonLoader with the legacy install rules (original
per-directory routing).
Sourcepub fn with_default_recursive_rules() -> Self
pub fn with_default_recursive_rules() -> Self
Creates a MelonLoader with the recursive install rules (all files go
into Mods).
Sourcepub fn set_exclude(&mut self, exclude: GlobSet)
pub fn set_exclude(&mut self, exclude: GlobSet)
Sets a glob set of files to exclude from installation.
Sourcepub fn add_install_rule(&mut self, rule: InstallRule)
pub fn add_install_rule(&mut self, rule: InstallRule)
Adds an install rule to the end of the ruleset.