Mod loader definitions and launch-argument generation for the loadsmith mod-manager library.
This is an internal crate of the [loadsmith] workspace. Most consumers
should depend on the loadsmith facade crate instead of using this
crate directly.
Examples
use loadsmith_loader::{BepInEx, Loader};
let loader = BepInEx::with_default_rules();
assert_eq!(loader.id(), "BepInEx");Modules
Macros
- glob
- Creates a
globset::Globfrom a string literal, panicking if the pattern is invalid. - glob_
rule - Creates a
loadsmith_install::GlobRulefrom a pattern and destination path literal, panicking if the pattern is invalid.
Structs
- BepInEx
- Loader implementation for BepInEx, a general-purpose Unity mod loader.
- Bepis
Loader - Loader implementation for BepisLoader, a mod loader for Honey Select / Koikatsu that wraps BepInEx with a renderer-specific plugin directory.
- GDWeave
- Loader implementation for GDWeave, a mod loader for the game WEBFISHING.
- Launch
Args - Arguments, environment variables, and an optional wrapper binary to use when launching a game with a mod loader.
- Launch
Context - Information about the game and profile directories used when launching a loader.
- Lovely
- Loader implementation for Lovely, a mod loader for the visual-novel game Doki Doki Literature Club!.
- Melon
Loader - Loader implementation for MelonLoader, a mod loader for Unity games.
- Northstar
- Loader implementation for Northstar, a mod loader for Titanfall 2.
- Return
OfModding - Loader implementation for Return of Modding (ROM), a mod loader for the game Hellsmith.
- Rivet
- Loader implementation for Rivet, a mod loader for Lethal Company.
- Shimloader
- Loader implementation for Unreal Shimloader, a UE4SS-based mod loader for games like HoloCure.
Enums
- Error
- Errors that can occur during loader setup and launch-argument generation.
Traits
- Loader
- A mod loader definition that knows how to install packages and generate launch arguments for a target game.
Type Aliases
- Result
- Convenience alias for
Result<T, loadsmith_loader::Error>.