docs.rs failed to build loadsmith-loader-0.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
loadsmith-loader-0.3.1
Mod loader definitions and launch-argument generation for the loadsmith mod-manager library.
This is an internal crate of the [loadsmith] workspace. Most consumers
should depend on the loadsmith facade crate instead of using this
crate directly.