pub struct Northstar { /* private fields */ }Expand description
Loader implementation for Northstar, a mod loader for Titanfall 2.
Northstar places packages into R2Northstar/mods and launches with
-northstar -profile=<path>. It excludes common metadata files
(manifest.json, README.md, icon.png, LICENSE) from installation.
Examples
use loadsmith_loader::{Northstar, Loader};
let loader = Northstar::with_default_rules();
assert_eq!(loader.id(), "Northstar");Implementations
Sourceimpl Northstar
impl Northstar
Sourcepub fn with_rules(package_install_ruleset: OwnedInstallRuleset) -> Self
pub fn with_rules(package_install_ruleset: OwnedInstallRuleset) -> Self
Creates a Northstar loader with a custom install ruleset.
Sourcepub fn with_default_rules() -> Self
pub fn with_default_rules() -> Self
Creates a Northstar loader with the default rules.
Files are routed into R2Northstar/mods. Metadata files
(manifest.json, README.md, icon.png, LICENSE) are excluded.
Sourcepub fn add_install_rule(&mut self, rule: impl Into<InstallRule>)
pub fn add_install_rule(&mut self, rule: impl Into<InstallRule>)
Adds an install rule to the end of the ruleset.
Sourcepub fn insert_install_rule(
&mut self,
index: usize,
rule: impl Into<InstallRule>,
)
pub fn insert_install_rule( &mut self, index: usize, rule: impl Into<InstallRule>, )
Inserts an install rule at the given index.